@@ -28,8 +28,6 @@
 
 #include "translator.icc"
 
-using std::vector;
-
 /*
  * This class implements an engraver for custos symbols.
  *
@@ -48,8 +46,8 @@ public:
 
 private:
   Item *create_custos ();
-  vector<Grob *> custodes_;
-  vector<Pitch> pitches_;
+  std::vector<Grob *> custodes_;
+  std::vector<Pitch> pitches_;
 };
 
 Custos_engraver::Custos_engraver (Context *c)
@@ -87,7 +85,8 @@ Custos_engraver::acknowledge_note_head (Grob_info info)
         don't look at the staff-position, since we can't be sure
         whether Clef_engraver already applied a vertical shift.
       */
-      pitches_.push_back (*unsmob<Pitch> (get_property (ev, "pitch")));
+      if (Pitch *p = unsmob<Pitch> (get_property (ev, "pitch")))
+        pitches_.push_back (*p);
     }
 }
 
