@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2005--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2005--2023 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -21,8 +21,7 @@
 #include "grob-array.hh"
 #include "grob.hh"
 
-LY_DEFINE (ly_grob_array_length, "ly:grob-array-length",
-           1, 0, 0,
+LY_DEFINE (ly_grob_array_length, "ly:grob-array-length", 1, 0, 0,
            (SCM grob_arr),
            R"(
 Return the length of @var{grob-arr}.
@@ -33,8 +32,7 @@ Return the length of @var{grob-arr}.
   return to_scm (me->size ());
 }
 
-LY_DEFINE (ly_grob_array_ref, "ly:grob-array-ref",
-           2, 0, 0,
+LY_DEFINE (ly_grob_array_ref, "ly:grob-array-ref", 2, 0, 0,
            (SCM grob_arr, SCM index),
            R"(
 Retrieve the @var{index}th element of @var{grob-arr}.
@@ -50,9 +48,7 @@ Retrieve the @var{index}th element of @var{grob-arr}.
   return me->grob (i)->self_scm ();
 }
 
-LY_DEFINE (ly_grob_array_2_list, "ly:grob-array->list",
-           1, 0, 0,
-           (SCM grob_arr),
+LY_DEFINE (ly_grob_array_2_list, "ly:grob-array->list", 1, 0, 0, (SCM grob_arr),
            R"(
 Return the elements of @var{grob-arr} as a Scheme list.
            )")
@@ -62,8 +58,7 @@ Return the elements of @var{grob-arr} as a Scheme list.
   return grob_array_to_list (me);
 }
 
-LY_DEFINE (ly_grob_list_2_grob_array, "ly:grob-list->grob-array",
-           1, 0, 0,
+LY_DEFINE (ly_grob_list_2_grob_array, "ly:grob-list->grob-array", 1, 0, 0,
            (SCM grob_list),
            R"(
 Convert a Scheme list of grobs to a grob array.
