@@ -35,8 +35,6 @@
 
 #include "translator.icc"
 
-using std::vector;
-
 /*
  * TODO: accidentals are aligned with the first note;
  * they must appear ahead.
@@ -60,17 +58,18 @@ class Mensural_ligature_engraver : public Coherent_ligature_engraver
 protected:
   Spanner *create_ligature_spanner () override;
   void build_ligature (Spanner *ligature,
-                       vector<Item *> const &primitives) override;
+                       std::vector<Item *> const &primitives) override;
 
 public:
   TRANSLATOR_DECLARATIONS (Mensural_ligature_engraver);
 
 private:
-  void transform_heads (vector<Item *> const &primitives);
+  void transform_heads (std::vector<Item *> const &primitives);
   void propagate_properties (Spanner *ligature,
-                             vector<Item *> const &primitives,
+                             std::vector<Item *> const &primitives,
                              Real &min_length);
-  void fold_up_primitives (vector<Item *> const &primitives, Real &min_length);
+  void fold_up_primitives (std::vector<Item *> const &primitives,
+                           Real &min_length);
 };
 
 Mensural_ligature_engraver::Mensural_ligature_engraver (Context *c)
@@ -87,11 +86,12 @@ Mensural_ligature_engraver::create_ligature_spanner ()
 }
 
 void
-Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
+Mensural_ligature_engraver::transform_heads (
+  std::vector<Item *> const &primitives)
 {
   if (primitives.size () < 2)
     {
-      warning (_ ("ligature with less than 2 heads -> skipping"));
+      warning (_ ("ligature with less than 2 heads; skipping"));
       return;
     }
   int prev_pitch = 0;
@@ -117,41 +117,41 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
       if (!nr->in_event_class ("note-event"))
         {
           nr->warning (
-            _ ("cannot determine pitch of ligature primitive -> skipping"));
+            _ ("cannot determine pitch of ligature primitive; skipping"));
           at_beginning = true;
           continue;
         }
 
       int pitch = unsmob<Pitch> (get_property (nr, "pitch"))->steps ();
       int prim = 0;
+      bool const is_last = i == s - 1;
 
       if (at_beginning)
         {
-          if (i == s - 1)
+          if (is_last)
             {
               // we can get here after invalid input
-              nr->warning (_ ("single note ligature - skipping"));
+              nr->warning (_ ("single note ligature; skipping"));
               break;
             }
           prev_semibrevis = prev_brevis_shape = false;
           prev_primitive = NULL;
         }
-      else
+      else if (pitch == prev_pitch)
         {
-          if (pitch == prev_pitch)
-            {
-              nr->warning (_ ("prime interval within ligature -> skipping"));
-              at_beginning = true;
-              prim = MLP_NONE;
-              continue;
-            }
+          nr->warning (_ ("prime interval within ligature; skipping"));
+          at_beginning = true;
+          prim = MLP_NONE;
+          continue;
         }
 
       if (duration_log < -3 // is this possible at all???
           || duration_log > 0)
         {
           nr->warning (
-            _ ("mensural ligature: duration none of Mx, L, B, S -> skipping"));
+            _ ("mensural ligature:"
+               " duration none of maxima, longa, breve, or semibreve;"
+               " skipping"));
           prim = MLP_NONE;
           at_beginning = true;
           continue;
@@ -160,32 +160,26 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
       bool general_case = true;
       bool make_flexa = false;
       bool allow_flexa = true;
+      bool const is_brevis = duration_log == -1;
 
       // first check special cases
-      // 1. beginning
-      if (at_beginning)
+      // 1. initial longa or brevis
+      if (at_beginning && 0 > duration_log && duration_log > -3)
         {
-          // a. semibreves
-          if (duration_log == 0)
+          // descendens
+          if (unsmob<Pitch>
+              (get_property (primitives[i + 1]->event_cause (), "pitch"))
+                  ->steps ()
+                < pitch
+              || (is_brevis && from_scm<bool>
+                  (get_property (primitive, "left-down-stem"))))
             {
-              prim = MLP_UP | MLP_BREVIS;
-              general_case = false;
-            }
-          // b. descendens longa or brevis
-          else if (i < s - 1
-                   && (unsmob<Pitch> (
-                         get_property (primitives[i + 1]->event_cause (),
-                                       "pitch"))
-                         ->steps ()
-                       < pitch)
-                   && duration_log > -3)
-            {
-              int left_stem = duration_log == -1 ? MLP_DOWN : 0;
+              int left_stem = is_brevis ? MLP_DOWN : 0;
               prim = left_stem | MLP_BREVIS;
               general_case = false;
             }
         }
-      // 2. initial semibrevis must not be followed by a brevis
+      // 2. semibrevis must not be followed by a brevis
       //    (theoretical sources require semibrevis, but
       //     longa and maxima can be denoted unambiguously,
       //     and in extremely rare cases these are used,
@@ -202,27 +196,28 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
           else
             {
               nr->warning (
-                _ ("semibrevis must not be followed by a brevis -> skipping"));
+                _ ("semibrevis must not be followed by a brevis; skipping"));
               prim = MLP_NONE;
               at_beginning = true;
               continue;
             }
         }
-      // 3. semibreves are otherwise not allowed
+      // 3. semibreves are denoted by an upward tail on the left
+      //    (theoretical sources require them at the beginning, but
+      //     an upward tail is not used for anything else in the middle,
+      //     and in extremely rare cases it's used to denote semibreves,
+      //     see e.g. Fayrfax's Aeternae laudis lilium
+      //     in the Lambeth Choirbook: fol. 58v, start of the fourth line)
       else if (duration_log == 0)
         {
-          nr->warning (
-            _ ("semibreves can only appear at the beginning of a ligature,\n"
-               "and there may be at most two of them"));
-          prim = MLP_NONE;
-          at_beginning = true;
-          continue;
+          prim = MLP_UP | MLP_BREVIS;
+          general_case = false;
         }
       // 4. end, descendens
-      else if (i == s - 1 && pitch < prev_pitch)
+      else if (is_last && pitch < prev_pitch)
         {
           // brevis; previous note must be turned into flexa
-          if (duration_log == -1)
+          if (is_brevis)
             {
               if (prev_brevis_shape)
                 {
@@ -231,19 +226,26 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
                 }
               else
                 {
-                  nr->warning (_ ("invalid ligatura ending:\n"
+                  nr->warning (_ ("invalid ligature ending:\n"
                                   "when the last note is a descending brevis,\n"
                                   "the penultimate note must be another one,\n"
-                                  "or the ligatura must be LB or SSB"));
+                                  "or the ligature must be longa-brevis or\n"
+                                  "semibrevis-semibrevis-brevis"));
                   prim = MLP_NONE;
                   break;
                 }
             }
           // longa
-          else if (duration_log == -2 && ! prev_semibrevis)
+          else if (duration_log == -2 && !prev_semibrevis
+                   && !from_scm<bool>
+                     (get_property (primitive, "right-down-stem")))
             {
               prim = MLP_BREVIS;
               general_case = allow_flexa = false;
+              if (from_scm<bool> (get_property (primitive, "right-up-stem")))
+                {
+                  prim |= MLP_JOIN_UP;
+                }
             }
           // else maxima (or longa-after-semibrevis);
           // fall through to regular case below
@@ -258,10 +260,12 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
             - both of the notes must be of brevis shape
               (i.e. can't be maxima or flexa;
               longa is forbidden as well - it's nonexistent anyway)
+            - there mustn't be a stem here
             - no compulsory flexa for the next note,
               i.e. it's not an ultimate descending breve
           */
-          make_flexa = !at_beginning && prev_brevis_shape && duration_log > -2;
+          make_flexa = !at_beginning && prev_brevis_shape && duration_log > -2
+            && !(prim & MLP_STEM);
           if (make_flexa && i == s - 2)
             {
               /*
@@ -291,6 +295,14 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
           static int const shape[3] = {MLP_MAXIMA, MLP_LONGA, MLP_BREVIS};
 
           prim = shape[duration_log + 3];
+          if (duration_log == -3)
+            {
+              if (from_scm<bool> (get_property (primitive, "right-down-stem")))
+                prim |= MLP_JOIN_DOWN;
+              else if (is_last && from_scm<bool>
+                       (get_property (primitive, "right-up-stem")))
+                prim |= MLP_JOIN_UP;
+            }
         }
 
       if (make_flexa)
@@ -339,7 +351,7 @@ Mensural_ligature_engraver::transform_heads (vector<Item *> const &primitives)
  */
 void
 Mensural_ligature_engraver::propagate_properties (
-  Spanner *ligature, vector<Item *> const &primitives, Real &min_length)
+  Spanner *ligature, std::vector<Item *> const &primitives, Real &min_length)
 {
   Real thickness = from_scm<double> (get_property (ligature, "thickness"), 1.3);
   thickness
@@ -356,9 +368,10 @@ Mensural_ligature_engraver::propagate_properties (
 
   min_length = 0.0;
   Item *prev_primitive = NULL;
+  int prev_output;
   for (const auto &primitive : primitives)
     {
-      int output = from_scm<int> (get_property (primitive, "primitive"));
+      int const output = from_scm<int> (get_property (primitive, "primitive"));
       set_property (primitive, "thickness", to_scm (thickness));
 
       switch (output & MLP_ANY)
@@ -393,13 +406,23 @@ Mensural_ligature_engraver::propagate_properties (
           break;
         }
 
+      /*
+        join to the previous notehead is handled with the previous note.
+        let it know when this note has a left stem,
+        as it mustn't be hidden by the join
+      */
+      if (prev_primitive && (output & MLP_UP))
+        set_property (prev_primitive, "primitive",
+                      to_scm (prev_output | MLP_JOIN_UP));
+
       prev_primitive = primitive;
+      prev_output = output;
     }
 }
 
 void
 Mensural_ligature_engraver::fold_up_primitives (
-  vector<Item *> const &primitives, Real &min_length)
+  std::vector<Item *> const &primitives, Real &min_length)
 {
   Item *first = 0;
   Real distance = 0.0;
@@ -482,8 +505,8 @@ Mensural_ligature_engraver::fold_up_primitives (
 }
 
 void
-Mensural_ligature_engraver::build_ligature (Spanner *ligature,
-                                            vector<Item *> const &primitives)
+Mensural_ligature_engraver::build_ligature (
+  Spanner *ligature, std::vector<Item *> const &primitives)
 {
   /*
     the X extent of the actual graphics representing the ligature;
