@@ -22,8 +22,6 @@
 #include "lily-guile.hh"
 #include "warn.hh"
 
-using std::string;
-
 const char *const Moment::type_p_name_ = "ly:moment?";
 
 int
@@ -101,10 +99,10 @@ Moment::operator%= (Rational const &r)
   return *this;
 }
 
-string
+std::string
 Moment::to_string () const
 {
-  string s = main_part_.to_string ();
+  std::string s = main_part_.to_string ();
   if (grace_part_)
     s += "G" + grace_part_.to_string ();
   return s;
@@ -119,15 +117,6 @@ Moment::operator- () const
   return m;
 }
 
-#ifdef STREAM_SUPPORT
-ostream &
-operator<< (ostream &os, Moment const &m)
-{
-  os << m.to_string ();
-  return os;
-}
-#endif
-
 bool
 moment_less (SCM a, SCM b)
 {
