@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1998--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1998--2023 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,8 +41,8 @@ Music_wrapper_iterator::derived_mark () const
 }
 
 void
-Music_wrapper_iterator::preorder_walk
-(const std::function <void (Music_iterator *)> &visit)
+Music_wrapper_iterator::preorder_walk (
+  const std::function<void (Music_iterator *)> &visit)
 {
   Music_iterator::preorder_walk (visit);
   if (child_iter_)
