@@ -22,15 +22,6 @@
 #include "open-type-font.hh"
 #include "freetype.hh"
 
-#ifdef FT_FONT_FORMATS_H
-/* FreeType 2.6+ */
-#include FT_FONT_FORMATS_H
-#else
-/* FreeType 2.5.5 and earlier */
-#include FT_XFREE86_H
-#define FT_Get_Font_Format FT_Get_X11_Font_Format
-#endif
-
 #include <cstdio>
 
 LY_DEFINE (ly_otf_font_glyph_info, "ly:otf-font-glyph-info", 2, 0, 0,
@@ -68,13 +59,18 @@ non-existent @var{tag}.
 
   SCM_ASSERT_TYPE (otf, font, SCM_ARG1, __FUNCTION__, "OpenType font");
   LY_ASSERT_TYPE (scm_is_string, tag, 2);
-
-  char ctag[5] = "    ";
-
   std::string tag_string = ly_scm2string (tag);
-  strncpy (ctag, tag_string.c_str (), tag_string.length ());
+  if (tag_string.length () > 4)
+    {
+      scm_misc_error ("ly:otf-font-table-data",
+                      "tag string must have 4 characters at most: ~s",
+                      ly_list (tag));
+    }
 
-  std::string tab = otf->get_otf_table (std::string (ctag));
+  // Pad with spaces
+  tag_string.insert (tag_string.length (), 4 - tag_string.length (), ' ');
+
+  std::string tab = otf->load_font_table (tag_string);
 
   SCM ret = scm_from_latin1_stringn (tab.data (), tab.length ());
   scm_remember_upto_here_1 (font);
@@ -168,7 +164,8 @@ TTC/OTC. The default value of @var{idx} is@tie{}0.
     }
 
   face = open_ft_face (file_name, i);
-  SCM asscm = scm_from_latin1_symbol (FT_Get_Font_Format (face));
+  std::string font_format = get_font_format (face);
+  SCM asscm = scm_from_latin1_symbol (font_format.c_str ());
   FT_Done_Face (face);
 
   return asscm;
