@@ -32,24 +32,15 @@
 
 struct Tuplet_description
 {
-  Stream_event *event_;
-  Spanner *bracket_;
-  Spanner *number_;
+  Stream_event *event_ = nullptr;
+  Spanner *bracket_ = nullptr;
+  Spanner *number_ = nullptr;
 
-  bool full_length_;
-  bool full_length_note_;
+  bool full_length_ = false;
+  bool full_length_note_ = false;
   Moment stop_moment_;
   Moment start_moment_;
   Moment length_;
-
-  Tuplet_description ()
-  {
-    event_ = 0;
-    full_length_note_ = false;
-    full_length_ = false;
-    bracket_ = 0;
-    number_ = 0;
-  }
 };
 
 class Tuplet_engraver : public Engraver
@@ -61,7 +52,6 @@ protected:
   std::vector<Tuplet_description> tuplets_;
   std::vector<Tuplet_description> new_tuplets_;
   std::vector<Tuplet_description> stopped_tuplets_;
-  std::vector<Spanner *> last_tuplets_;
 
   void acknowledge_note_column (Grob_info_t<Item>);
   void acknowledge_script (Grob_info);
@@ -134,37 +124,35 @@ Tuplet_engraver::process_music ()
       auto *number = tuplet.number_;
       if (bracket)
         {
-          if (tuplet.full_length_)
+          if (Grob *left = bracket->get_bound (LEFT))
             {
-              auto *col = unsmob<Item> (
-                tuplet.full_length_note_
-                  ? get_property (this, "currentMusicalColumn")
-                  : get_property (this, "currentCommandColumn"));
+              if (tuplet.full_length_)
+                {
+                  auto *col = unsmob<Item> (
+                    tuplet.full_length_note_
+                      ? get_property (this, "currentMusicalColumn")
+                      : get_property (this, "currentCommandColumn"));
 
-              bracket->set_bound (RIGHT, col);
-              number->set_bound (RIGHT, col);
+                  bracket->set_bound (RIGHT, col);
+                  number->set_bound (RIGHT, col);
+                }
+              else if (!bracket->get_bound (RIGHT))
+                {
+                  // This tuplet only spans one note, e.g.,
+                  // \tuplet 3/2 { s8 c'8 s8 }.
+                  bracket->set_bound (RIGHT, left);
+                  number->set_bound (RIGHT, left);
+                }
             }
-          else if (!bracket->get_bound (RIGHT))
+          else
             {
-              if (auto *bound = bracket->get_bound (LEFT))
-                {
-                  bracket->set_bound (RIGHT, bound);
-                  number->set_bound (RIGHT, bound);
-                }
-              else
-                {
-                  warning (_ ("omitting tuplet bracket with neither left nor "
-                              "right bound"));
-                  continue;
-                }
+              // This tuplet spans no notes at all, e.g.,
+              // \tuplet 3/2 { s8 s8 s8 }.  Remove it.
+              bracket->suicide ();
+              number->suicide ();
             }
-          // todo: scrap last_tuplets_, use stopped_tuplets_ only.
-          // clear stopped_tuplets_ at start_translation_timestep
-          last_tuplets_.push_back (bracket);
-          last_tuplets_.push_back (number);
         }
     }
-  stopped_tuplets_.clear ();
 
   tuplets_.insert (tuplets_.end (), new_tuplets_.begin (), new_tuplets_.end ());
   new_tuplets_.clear ();
@@ -256,7 +244,7 @@ Tuplet_engraver::add_script_to_all_tuplets (Item *script)
 void
 Tuplet_engraver::start_translation_timestep ()
 {
-  last_tuplets_.clear ();
+  stopped_tuplets_.clear ();
   /*
     May seem superfluous, but necessary for skipTypesetting.
    */
@@ -266,12 +254,14 @@ Tuplet_engraver::start_translation_timestep ()
 void
 Tuplet_engraver::finalize ()
 {
-  if (from_scm<bool> (get_property (this, "tupletFullLength")))
-    for (vsize i = 0; i < last_tuplets_.size (); i++)
-      {
-        Item *col = unsmob<Item> (get_property (this, "currentCommandColumn"));
-        last_tuplets_[i]->set_bound (RIGHT, col);
-      }
+  // If tupletFullLengthNote is used, fix up bounds to avoid grobs extending to
+  // the musical column of the last time step, which is after the end of the
+  // piece.
+  Item *col = unsmob<Item> (get_property (this, "currentCommandColumn"));
+  for (Tuplet_description &desc : stopped_tuplets_)
+    if (desc.full_length_note_)
+      for (Spanner *g : {desc.bracket_, desc.number_})
+        g->set_bound (RIGHT, col);
 }
 
 Tuplet_engraver::Tuplet_engraver (Context *c)
