@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2022 Daniel Eble <nine.fierce.ballads@gmail.com>
+;;;; Copyright (C) 2022--2023 Daniel Eble <nine.fierce.ballads@gmail.com>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
 
 (define-public default-breath-alist
   `(
+    (altcomma
+     . (
+        (text . ,(make-musicglyph-markup "scripts.raltcomma"))))
     (caesura
      . (
         (text . ,(make-musicglyph-markup "scripts.caesura.straight"))))
