@@ -256,7 +256,8 @@ expression."
                            'GraceMusic
                            element (music
                                     'SequentialMusic
-                                    elements (?start
+                                    elements (?init-context
+                                              ?start
                                               ?music
                                               ?stop))))
                     ;; we check whether ?start and ?stop look like
@@ -287,7 +288,8 @@ expression."
                            'GraceMusic
                            element (music
                                     'SequentialMusic
-                                    elements (?start
+                                    elements (?init-context
+                                              ?start
                                               ?music
                                               ?stop))))
                     ;; we check whether ?start and ?stop look like
@@ -331,7 +333,8 @@ expression."
                            'GraceMusic
                            element (music
                                     'SequentialMusic
-                                    elements (?start
+                                    elements (?init-context
+                                              ?start
                                               ?music
                                               ?stop))))
                     ;; we check whether ?start and ?stop look like
@@ -622,7 +625,7 @@ expression."
       "\\["
       "\\]"))
 
-(define-display-method BarCheck (check)
+(define-display-method BarCheckEvent (check)
   (format #f "|~a" (new-line->lily-string)))
 
 (define-display-method PesOrFlexaEvent (expr)
@@ -796,6 +799,10 @@ expression."
             (parameterize ((*current-context* ctype))
               (music->lily-string music)))))
 
+(define-display-method InitialContextMusic (expr)
+  (let ((music (ly:music-property expr 'element)))
+    (format #f "\\initialContextFrom ~a" (music->lily-string music))))
+
 ;; \after
 (define-extra-display-method ContextSpeccedMusic (expr)
   "If `expr' is an \\after expression with a post-event, return
