@@ -682,6 +682,7 @@ determines the number of scale steps that make up an octave.  Usually the
     (,markup-command-list? . "markup command list")
     (,markup-list? . "markup list")
     (,moment-pair? . "pair of moment objects")
+    (,musical-length? . "non-negative moment with no grace part")
     (,non-negative-number? . "non-negative number")
     (,number-list? . "number list")
     (,number-or-grob? . "number or grob")
@@ -689,6 +690,8 @@ determines the number of scale steps that make up an octave.  Usually the
     (,number-or-string? . "number or string")
     (,number-pair? . "pair of numbers")
     (,number-pair-list? . "list of number pairs")
+    (,positive-fraction? . "positive, finite fraction, as pair")
+    (,positive-musical-length? . "positive moment with no grace part")
     (,positive-number? . "positive number")
     (,exact-rational? . "an exact rational number")
     (,rational-or-procedure? . "an exact rational or procedure")
